==> haskell-smallcheck-1.2.1-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smallcheck
version:              1.2.1
visibility:           public
id:                   smallcheck-1.2.1-G9zZIUPjCG1RXPmMpkdFa
key:                  smallcheck-1.2.1-G9zZIUPjCG1RXPmMpkdFa
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  eed6e335c1fca502e10966d6d76c7cd4
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-8.10.4/site-local/smallcheck-1.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/smallcheck-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/smallcheck-1.2.1
hs-libraries:         HSsmallcheck-1.2.1-G9zZIUPjCG1RXPmMpkdFa
depends:
    base-4.14.1.0 logict-0.7.1.0-HSGM0xBuBB6G9ch5iSaI9E mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smallcheck-1.2.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smallcheck
version:              1.2.1
visibility:           public
id:                   smallcheck-1.2.1-IWsPHf4blAP1pbXPDpZbT5
key:                  smallcheck-1.2.1-IWsPHf4blAP1pbXPDpZbT5
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  681d530dd18297ea46b7a10896562bb3
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-8.10.4/site-local/smallcheck-1.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/smallcheck-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/smallcheck-1.2.1
hs-libraries:         HSsmallcheck-1.2.1-IWsPHf4blAP1pbXPDpZbT5
depends:
    base-4.14.1.0 logict-0.7.1.0-hDOH3QnhVPKXsvIVYjDhc mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
